/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.auth.domain.user.User;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.locationtech.jts.geom.Point;

/**
 * 围栏报警记录
 *
 * @author Jim
 * @version 0.1
 * 2022/5/12 21:33
 */

@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(name = "BS_LOCATION_FENCE_ALARM")
@Comment("围栏报警记录")
public class LocationFenceAlarm extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 2984248537199016912L;

    @Comment("围栏")
    @ManyToOne(fetch = FetchType.LAZY)
    LocationFence fence;

    @Comment("触警位置")
    @Column(columnDefinition = "geometry(Point,4326)")
    Point point;

    @Comment("地图编号")
    Long areaId;

    @Comment("触警人员")
    @ManyToOne(fetch = FetchType.LAZY)
    User user;

    @Comment("触警标签")
    @ManyToOne(fetch = FetchType.LAZY)
    LocationTag tag;

    @Comment("报警开始时间")
    LocalDateTime startTime;

    @Comment("报警结束时间")
    LocalDateTime endTime;

    @Comment("报警类型")
    @ManyToOne(fetch = FetchType.LAZY)
    AlarmType type;

    @Comment("状态")
    @Enumerated(EnumType.STRING)
    Status status;

    // 推送记录集合（含接收状态）
    // TODO

    @SuppressWarnings({ "unused" })
    public enum Status {
        ING("进行中"),
        OVER("结束");

        final String text;

        Status(String text) {
            this.text = text;
        }

        public String text() {
            return this.text;
        }

        public static Status get(boolean flag) {
            return flag ? ING : OVER;
        }
    }
}
