/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.location;

import com.alibaba.fastjson.JSON;
import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.constant.alarm.InformMannerEnum;
import com.yiring.app.domain.location.LocationAlarmRule;
import com.yiring.auth.domain.user.User;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/6 11:11
 */
@ExcelModel
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class LocationAlarmRuleExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = -898420880457790036L;

    @ExcelColumn(title = "地图名称")
    private String mapName;

    @ExcelColumn(title = "电子围栏名称", width = 15)
    private String fenceName;

    @ExcelColumn(title = "接收人", width = 20)
    private String users;

    @ExcelColumn(title = "通知方式", width = 18)
    private String informManner;

    public static LocationAlarmRuleExcel transform(LocationAlarmRule locationAlarmRule) {
        StringBuilder usersBuilder = new StringBuilder();
        StringBuilder informManner = new StringBuilder();
        List<Integer> informMannerList = JSON.parseArray(locationAlarmRule.getInformManner(), Integer.class);
        for (User user : locationAlarmRule.getUsers()) {
            usersBuilder.append(", ");
            usersBuilder.append(user.getRealName());
        }
        String users = usersBuilder.substring(2);
        for (int i = 0; i < informMannerList.size(); i++) {
            if (i != 0) {
                informManner.append(", ");
            }
            informManner.append(InformMannerEnum.getByCode(informMannerList.get(i)));
        }
        return LocationAlarmRuleExcel
            .builder()
            .mapName(locationAlarmRule.getMapName())
            .fenceName(locationAlarmRule.getLocationFence().getName())
            .users(users.toString())
            .informManner(informManner.toString())
            .build();
    }
}
