/* (C) 2022 YiRing, Inc. */
package com.yiring.app.job;

import com.alibaba.fastjson.JSON;
import com.xxl.job.core.handler.annotation.XxlJob;
import com.yiring.app.design.strategy.rule.ScanAlarmContext;
import com.yiring.app.domain.location.*;
import com.yiring.app.param.location.fence.LocationFenceJobParam;
import com.yiring.app.param.location.rule.RuleParam;
import com.yiring.app.vo.location.fence.LocationFenceJobVo;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/14 10:10
 */
@Slf4j
@Component
public class FenceAlarmJob {

    @Resource
    private LocationFenceRepository locationFenceRepository;

    @Resource
    private LocationFenceAlarmRepository locationFenceAlarmRepository;

    @XxlJob("ScanAlarmHandler")
    @Transactional(rollbackFor = Exception.class)
    public void scanAlarmHandler() {
        //查询出所有已启用的电子围栏信息和正在报警的报警信息
        List<LocationFence> fenceList = locationFenceRepository.findAllByEnable(true);
        List<LocationFenceAlarm> alarmList = locationFenceAlarmRepository.findAllByStatus(
            LocationFenceAlarm.Status.ING
        );
        Map<Long, List<LocationFenceAlarm>> alarmMap = alarmList
            .stream()
            .collect(Collectors.groupingBy(e -> e.getFence().getId()));
        LocationFenceJobVo jobVo = LocationFenceJobVo
            .builder()
            .addAlarm(new ArrayList<>())
            .modifyAlarm(new ArrayList<>())
            .build();
        for (LocationFence fence : fenceList) {
            //获取该围栏下的所有报警规则
            Set<LocationFenceRule> fenceRuleSet = fence.getRules();
            for (LocationFenceRule fenceRule : fenceRuleSet) {
                RuleParam ruleParam = JSON.parseObject(fenceRule.getRule(), RuleParam.class);
                List<LocationFenceAlarm> oldAlarms = alarmMap.get(fence.getId());
                LocationFenceJobParam fenceJobParam = LocationFenceJobParam
                    .builder()
                    .rule(ruleParam)
                    .fenceId(fence.getId())
                    .alarmTypeId(fenceRule.getAlarmType().getId())
                    .tagSet(fence.getTags())
                    .mapId(fence.getMapId())
                    .geometry(fence.getGeometry())
                    .oldAlarms(oldAlarms)
                    .build();
                LocationFenceJobVo locationFenceJobVo = ScanAlarmContext.scanAlarm(
                    fenceRule.getRelevanceParamType(),
                    fenceJobParam
                );
                jobVo.merge(locationFenceJobVo);
            }
        }
        //添加报警和关闭报警
        locationFenceAlarmRepository.saveAllAndFlush(jobVo.getAddAlarm());
        List<Long> ids = jobVo.getModifyAlarm().stream().map(LocationFenceAlarm::getId).collect(Collectors.toList());
        locationFenceAlarmRepository.batchOver(ids, LocalDateTime.now());
        log.info(
            "FenceAlarmJob.scanAlarmHandler: 添加的报警:[{}], 关闭的报警:[{}]",
            JSON.toJSONString(jobVo.getAddAlarm()),
            JSON.toJSONString(jobVo.getModifyAlarm())
        );
    }
}
