/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.rehearsal;

import com.yiring.app.constant.rehearsal.RehearsalPlanStatusEnum;
import com.yiring.app.domain.rehearsal.AccidentSpot;
import com.yiring.app.domain.rehearsal.EvacuationZone;
import com.yiring.app.domain.rehearsal.RehearsalPlan;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/10 11:29
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ApiModel("演练计划新增param")
public class RehearsalPlanAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 6574628197950618904L;

    @ApiModelProperty(value = "演练主题", example = "红色演练", required = true)
    @NotEmpty(message = "演练主题不能为空")
    private String topical;

    @ApiModelProperty(value = "事故点id", example = "1522844636060585984", required = true)
    @NotNull(message = "事故点id不能为空")
    private Long accidentSpotId;

    @ApiModelProperty(value = "周边范围(事故点周围多少米)", example = "50", required = true)
    @NotNull(message = "周边范围不能为空")
    private Integer scope;

    @ApiModelProperty(value = "撤离区id", example = "1523562795864428544", required = true)
    @NotNull(message = "撤离区id不能为空")
    private Long evacuationZoneId;

    @ApiModelProperty(value = "风险程度", example = "1", required = true)
    @NotNull(message = "撤离区id不能为空")
    private Integer riskLevel;

    @ApiModelProperty(value = "事故信息", example = "气体泄露", required = true)
    @NotEmpty(message = "事故信息不能为空")
    private String accidentMsg;

    public RehearsalPlan transform() {
        AccidentSpot accidentSpot = AccidentSpot.builder().id(accidentSpotId).build();
        EvacuationZone evacuationZone = EvacuationZone.builder().id(evacuationZoneId).build();
        return RehearsalPlan
            .builder()
            .topical(topical)
            .accidentSpot(accidentSpot)
            .scope(scope)
            .evacuationZone(evacuationZone)
            .riskLevel(riskLevel)
            .accidentMsg(accidentMsg)
            .status(RehearsalPlanStatusEnum.UN_START.getCode())
            .deleted(false)
            .build();
    }
}
