/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.visitor;

import com.yiring.common.constant.RegEx;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import lombok.*;
import lombok.experimental.FieldDefaults;
import org.hibernate.annotations.Comment;

/**
 * @author tzl
 * 2022/4/11 14:00
 */
@ApiModel("CarParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class CarParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 521351582969232371L;

    @ApiModelProperty(value = "车牌号码", example = "湘A99999", required = true)
    @NotEmpty(message = "车牌号码不能为空")
    @Pattern(regexp = RegEx.CARNUM, message = "车牌号码格式不正确")
    String carNum;

    @ApiModelProperty(value = "车辆类型", example = "1")
    String carType;

    @ApiModelProperty(value = "标签卡", example = "BT82737612", required = true)
    String labelCard;

    @ApiModelProperty(value = "司机名称", example = "张三", required = true)
    String driverName;

    @ApiModelProperty(value = "司机电话", example = "17674741309", required = true)
    @Pattern(regexp = RegEx.MOBILE, message = "请输入正确的号码")
    String mobile;

    @ApiModelProperty(value = "所属公司", example = "壹润科技")
    String orgId;

    @Comment("被访人电话")
    @ApiModelProperty(value = "被访人电话", example = "17674741309")
    String intervieweeMobile;

    @Comment("被访人姓名")
    @ApiModelProperty(value = "被访人姓名", example = "李四")
    String intervieweeName;

    @Comment("来访原因")
    @ApiModelProperty(value = "来访原因", example = "工作")
    String reason;
}
