/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.excel.user;

import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.ObjectUtil;
import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.auth.domain.role.Role;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.Set;
import lombok.AccessLevel;
import lombok.Builder;
import lombok.Data;
import lombok.experimental.FieldDefaults;

/**
 * 用户导出
 *
 * @author LJ-2204
 * @date 2022/5/14
 */

@ExcelModel
@Data
@Builder
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserExportExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = 7198940635708381370L;

    @ApiModelProperty(value = "姓名", example = "张三")
    @ExcelColumn(title = "姓名")
    String realName;

    @ExcelColumn(title = "工号")
    @ApiModelProperty(value = "工号", example = "1234566")
    String uuid;

    @ExcelColumn(title = "部门名称")
    @ApiModelProperty(value = "部门名称", example = "研发")
    String deptName;

    @ExcelColumn(title = "手机号")
    @ApiModelProperty(value = "手机号", example = "13012345678")
    String mobile;

    @ExcelColumn(title = "角色")
    @ApiModelProperty(value = "角色", example = "系统管理员")
    String roles;

    @ExcelColumn(title = "最后登录时间")
    @ApiModelProperty(value = "最后登录时间", example = "2022-10-24 10:24:00")
    String lastLoginTime;

    @ExcelColumn(title = "状态")
    @ApiModelProperty(value = "状态", example = "true")
    Boolean enabled;

    public static UserExportExcel transform(User user) {
        UserExportExcel userExportExcel = UserExportExcel
            .builder()
            .realName(user.getRealName())
            .uuid(user.getUuid())
            .deptName(user.getDepartment().getName())
            .mobile(user.getMobile())
            .lastLoginTime(LocalDateTimeUtil.format(user.getLastLoginTime(), "yyyy-MM-dd HH:mm:ss"))
            .enabled(user.getEnabled())
            .build();

        if (ObjectUtil.isNotEmpty(user.getRoles())) {
            Set<Role> roles = user.getRoles();
            StringBuilder stringBuilder = new StringBuilder();
            roles.forEach(role -> stringBuilder.append(role.getName()).append(","));
            String substring = stringBuilder.substring(0, stringBuilder.length() - 1);

            userExportExcel.setRoles(substring);
        }

        return userExportExcel;
    }
}
